@@ -19,6 +19,8 @@ static const gchar *default_fonts [5] = {
 static void	graph_expose (GtkWidget *, GdkEventExpose *, Graph *);
 static void	graph_size_request (GtkWidget *, GtkRequisition *, Graph *);
 static gint	graph_configure (GtkWidget *, GdkEventConfigure *, Graph *);
+static void	graph_realize (GtkWidget *, Graph *);
+static void	graph_unrealize (GtkWidget *, Graph *);
 
 static GtkWidget *graph_properties_init (GnomePropertyObject *);
 static void	graph_properties_apply (GnomePropertyObject *);
@@ -110,6 +112,19 @@ graph_size_request (GtkWidget *widget,
 	requisition->height = g->minimum_height;
 }
 
+static void
+graph_realize (GtkWidget *widget, Graph *g)
+{
+	if (!g->colors_allocated)
+		graph_colors_set (g);
+}
+
+static void
+graph_unrealize (GtkWidget *widget, Graph *g)
+{
+	g->colors_allocated = 0;
+}
+
 Graph *
 graph_new (GtkWidget *da, GraphDataFunc d_fn, gpointer user_data)
 {
@@ -136,6 +151,10 @@ graph_new (GtkWidget *da, GraphDataFunc d_fn, gpointer user_data)
 			    (GtkSignalFunc) graph_expose, (gpointer) g);
 	gtk_signal_connect (GTK_OBJECT (g->da), "configure_event",
 			    (GtkSignalFunc) graph_configure, (gpointer) g);
+	gtk_signal_connect (GTK_OBJECT (g->da), "realize",
+			    (GtkSignalFunc) graph_realize, (gpointer) g);
+	gtk_signal_connect (GTK_OBJECT (g->da), "unrealize",
+			    (GtkSignalFunc) graph_unrealize, (gpointer) g);
 
 	graph_colors_set (g);
 
@@ -176,6 +195,9 @@ graph_process_data (Graph *g)
 	lines = total = 0;
 	w = h = 10;
 
+	if (!GTK_WIDGET_REALIZED (g->da))
+		return;
+
 	gtk_widget_ensure_style (g->da);
 
 	graph_font = gtop_properties.graph.font ?
@@ -183,9 +205,6 @@ graph_process_data (Graph *g)
 	
 	extra_height = gtop_properties.graph.extra_height;
 
-	if (!GTK_WIDGET_REALIZED (g->da))
-		gtk_widget_realize (g->da);
-
 	if (!g->colors_allocated) {
 		GdkColormap *cmap;
 		GtkStyle *style;
@@ -429,13 +448,13 @@ graph_colors_set (Graph *g)
 		
 		gdk_colormap_free_colors (cmap, g->foreground, 1);
 		gdk_colormap_free_colors (cmap, g->background, 1);
+		g->colors_allocated = 0;
 	}
 
 	g->colors = gtop_properties.graph.colors+2;
 	g->foreground = &gtop_properties.graph.colors [0];
 	g->background = &gtop_properties.graph.colors [1];
 	g->n = GRAPH_DEFAULT_COLORS;
-	g->colors_allocated = 0;
 }
 
 static void
