@@ -154,12 +154,11 @@ main (int argc, char *argv[])
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	gnome_init_with_popt_table ("gtop", VERSION, argc, argv, gtop_options, 0, &ctx);
+	gnome_init_with_popt_table ("gtop", VERSION, argc, argv,
+				    gtop_options, 0, &ctx);
 	
 	args = poptGetArgs (ctx);
 
-	gtop_parse_args ();
-
 	poptFreeContext (ctx);
 
 	/* Initialize LibGTop. */
