@@ -144,11 +144,12 @@ memusage_data_fn (Graph *graph, GraphCmd cmd, gpointer data, gint64 *ret)
 	case GRAPH_LABEL:
 
 		if (info->n > 1)
-			sprintf (buf, "%s (%2d) : %8Ldk",
-				 info->cmd, info->n, info->value);
+			sprintf (buf, "%s (%2d) : %8ldk",
+				 info->cmd, info->n,
+				 (unsigned long) info->value);
 		else
-			sprintf (buf, "%s      : %8Ldk",
-				 info->cmd, info->value);
+			sprintf (buf, "%s      : %8ldk",
+				 info->cmd, (unsigned long) info->value);
 
 		return buf;
 
