@@ -989,7 +989,17 @@ procview_update (GTopProcViewData *d)
 	switch (d->ftype) {
 	case GTOP_PROCVIEW_USER:
 		which = GLIBTOP_KERN_PROC_UID;
-		arg = getuid ();
+		if (d->select_pid != -1) {
+		  glibtop_proc_uid procuid;
+
+		  glibtop_get_proc_uid (&procuid, d->select_pid);
+		  if (procuid.flags & (1L << GLIBTOP_PROC_UID_UID))
+		    arg = procuid.uid;
+		  else
+		    arg = getuid ();
+		} else {
+		  arg = getuid ();
+		}
 		break;
 	default:
 		which = GLIBTOP_KERN_PROC_ALL;
