@@ -443,7 +443,7 @@ gtop_summary_destroy (GTopSummaryData *d)
 {
 	gtop_summary_unmap (d);
 
-	g_list_remove (summary_object_list, d);
+	summary_object_list = g_list_remove (summary_object_list, d);
 }
 
 GTopSummaryData *
@@ -829,7 +829,7 @@ gtop_statusbar_destroy (GTopStatusBarData *d)
 	if (d->status_loadavg_timeout > 0)
 		gtk_timeout_remove (d->status_loadavg_timeout);
 
-	g_list_remove (statusbar_object_list, d);
+	statusbar_object_list = g_list_remove (statusbar_object_list, d);
 }
 
 /* =======================================================================
@@ -1282,10 +1282,11 @@ summary_colors_properties_update (GnomePropertyObject *object)
 	for (c = summary_object_list; c; c = c->next) {
 		GTopSummaryData *d = c->data;
 		gint i;
-		
+
 		summary_update (d);
 
-		if (d->summary_cpu && SUMMARY_GRAPH_BIT (GRAPH_CPU))
+		if (d->summary_cpu && SUMMARY_GRAPH_BIT (GRAPH_CPU) &&
+		    GTK_WIDGET_REALIZED (d->summary_cpu))
 			gnome_proc_bar_update
 				(GNOME_PROC_BAR (d->summary_cpu),
 				 gtop_properties.summary_colors.cpu);
@@ -1293,23 +1294,27 @@ summary_colors_properties_update (GnomePropertyObject *object)
 #ifdef HAVE_LIBGTOP_SMP
 		for (i = 0; i < ncpu; i++)
 			if (d->summary_xcpu [i] &&
-			    SUMMARY_GRAPH_BIT (GRAPH_XCPU))
+			    SUMMARY_GRAPH_BIT (GRAPH_XCPU) &&
+			    GTK_WIDGET_REALIZED (d->summary_xcpu [i]))
 				gnome_proc_bar_update
 					(GNOME_PROC_BAR (d->summary_xcpu [i]),
 					 gtop_properties.summary_colors.cpu);
 #endif
 
-	if (d->summary_mem && SUMMARY_GRAPH_BIT (GRAPH_MEM))
+		if (d->summary_mem && SUMMARY_GRAPH_BIT (GRAPH_MEM) &&
+		    GTK_WIDGET_REALIZED (d->summary_mem))
 			gnome_proc_bar_update
 				(GNOME_PROC_BAR (d->summary_mem),
 				 gtop_properties.summary_colors.mem);
 
-	if (d->summary_swap && SUMMARY_GRAPH_BIT (GRAPH_SWAP))
+		if (d->summary_swap && SUMMARY_GRAPH_BIT (GRAPH_SWAP) &&
+		    GTK_WIDGET_REALIZED (d->summary_swap))
 			gnome_proc_bar_update
 				(GNOME_PROC_BAR (d->summary_swap),
 				 gtop_properties.summary_colors.swap);
 
-	if (d->summary_load && SUMMARY_GRAPH_BIT (GRAPH_LOAD))
+		if (d->summary_load && SUMMARY_GRAPH_BIT (GRAPH_LOAD) &&
+		    GTK_WIDGET_REALIZED (d->summary_load))
 			gnome_proc_bar_update
 				(GNOME_PROC_BAR (d->summary_load),
 				 gtop_properties.summary_colors.load);
